items property
The future that resolves to the list of individual item states within the dropdown.
Implementation
@protected
final Future<List<DropDownItemState<T>>> items;
The future that resolves to the list of individual item states within the dropdown.
@protected
final Future<List<DropDownItemState<T>>> items;