AsyncFieldFormController extension

Extension on BaseFormController to handle resolving asynchronous hidden fields.

Provides a method to resolve the value of an async hidden field and update its state within the form controller. If the future completes successfully, the field's value is updated and any error is cleared. If the future fails, the error is logged and the field's error state is updated.

Example usage:

final value = await formController.resolveAsyncField<String>('myAsyncField');
on

Methods

resolveAsyncField<T>(String fieldName) Future<T>

Available on BaseFormController<dynamic, Error, BaseBondFormState<dynamic, Error>>, provided by the AsyncFieldFormController extension

Resolves the value of an asynchronous hidden field and updates its state.