AsyncHiddenFieldState<T> constructor

AsyncHiddenFieldState<T>(
  1. T value, {
  2. required Future<T> pendingValue,
  3. String? error,
})

Creates a new instance of AsyncHiddenFieldState.

  • value The value associated with the hidden field (optional).
  • pendingValue The future value that will be loaded asynchronously.

Implementation

AsyncHiddenFieldState(
  T value, {
  required this.pendingValue,
  String? error,
}) : super(
        value: value,
        label: '',
        error: error,
        rules: const [],
      );