copyWithNullable method

  1. @override
AsyncRadioGroupFieldState<T> copyWithNullable({
  1. T? value,
})
override

A null-tolerant version of copyWith, allowing you to explicitly set fields to null.

This is useful for form reset behaviors like clearing a field's value or removing its error.

Implementation

@override
AsyncRadioGroupFieldState<T> copyWithNullable({
  T? value,
}) {
  return AsyncRadioGroupFieldState<T>(
    value as T,
    items: items,
    cachedItems: cachedItems,
    label: label,
    rules: rules,
    error: error,
  );
}