items property
The future that resolves to the list of individual radio button states within the group.
Implementation
@protected
final Future<List<RadioButtonFieldState<T>>> items;
The future that resolves to the list of individual radio button states within the group.
@protected
final Future<List<RadioButtonFieldState<T>>> items;