onSubmit abstract method
To be implemented by the subclass, detailing what should happen when a form is submitted.
Returns the result of a successful submission.
Implementation
Future<Success> onSubmit();
To be implemented by the subclass, detailing what should happen when a form is submitted.
Returns the result of a successful submission.
Future<Success> onSubmit();