DateAfter class

A validation rule that checks if a date is after a specified date.

This rule validates that the input date is chronologically after a specified date.

Inheritance

Constructors

DateAfter(DateTime date, {String? message})
Creates a new instance of the DateAfter validation rule.
DateAfter.fromString(String date, {String? format, String? message})
Creates a new instance of the DateAfter validation rule from a string representation.

Properties

date → DateTime
The date to compare against.
final
hashCode → int
The hash code for this object.
no setterinherited
l10n → ValidatorLocalizations
The ValidatorLocalizations instance used for localization of validation messages. It's obtained through a service locator (sl) for convenience.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

message(String fieldName) → String
Retrieves the validation message to be displayed.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validate(DateTime value, Map<String, FormFieldState> fields) → bool
Validates the given value against the validation rule.
override
validatorMessage(String fieldName) → String
Retrieves the validator message for the field.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited