FieldBondFormState extension

Extension methods for BondFormState providing convenience operations.

The FieldBondFormState extension adds methods to BondFormState to simplify retrieving field states from the form state.

Example usage:

// Retrieve the state of a text field.
final phoneNumberFieldState = state.textField('phoneNumber');

Methods:

on

Methods

asyncDropDownField<T>(String fieldName) → AsyncDropDownFieldState<T>

Available on BaseBondFormState<dynamic, Error>, provided by the FieldBondFormState extension

Retrieves the state of the async dropdown field for a specified fieldName.
asyncDropDownItems<T>(String fieldName) → Future<List<DropDownItemState<T>>>

Available on BaseBondFormState<dynamic, Error>, provided by the FieldBondFormState extension

Retrieves the list of dropdown items for a specified fieldName.
asyncHiddenField<T>(String fieldName) → AsyncHiddenFieldState<T>

Available on BaseBondFormState<dynamic, Error>, provided by the FieldBondFormState extension

Retrieves the async hidden field state for a specified fieldName.
asyncRadioButtonsOf<T>(String fieldName) → Future<List<RadioButtonFieldState<T>>>

Available on BaseBondFormState<dynamic, Error>, provided by the FieldBondFormState extension

Retrieves a list of RadioButtonFieldState for a specified fieldName.
asyncRadioGroup<T>(String fieldName) → AsyncRadioGroupFieldState<T>

Available on BaseBondFormState<dynamic, Error>, provided by the FieldBondFormState extension

Retrieves the state of the async radio group field for a specified fieldName.
checkbox(String fieldName) → CheckboxFieldState<bool>

Available on BaseBondFormState<dynamic, Error>, provided by the FieldBondFormState extension

Retrieves the state of the checkbox field for a specified fieldName.
checkboxesOf<T>(String fieldName) → List<CheckboxFieldState<T>>

Available on BaseBondFormState<dynamic, Error>, provided by the FieldBondFormState extension

Retrieves a list of CheckboxFieldState for a specified fieldName.
checkboxGroup<T>(String fieldName) → CheckboxGroupFieldState<T>

Available on BaseBondFormState<dynamic, Error>, provided by the FieldBondFormState extension

Retrieves the state of the checkbox group field for a specified fieldName.
dateField(String fieldName) → DateFieldState

Available on BaseBondFormState<dynamic, Error>, provided by the FieldBondFormState extension

Retrieves the state of the date field for a specified fieldName.

Available on BaseBondFormState<dynamic, Error>, provided by the FieldBondFormState extension

Retrieves the state of the dropdown field for a specified fieldName.

Available on BaseBondFormState<dynamic, Error>, provided by the FieldBondFormState extension

Retrieves the list of dropdown items for a specified fieldName.
fileField(String fieldName) → FileFieldState

Available on BaseBondFormState<dynamic, Error>, provided by the FieldBondFormState extension

Retrieves the state of the file field for a specified fieldName.
hiddenField<T>(String fieldName) → HiddenFieldState<T>

Available on BaseBondFormState<dynamic, Error>, provided by the FieldBondFormState extension

Retrieves the hidden field state for a specified fieldName.
radioButtonsOf<T>(String fieldName) → List<RadioButtonFieldState<T>>

Available on BaseBondFormState<dynamic, Error>, provided by the FieldBondFormState extension

Retrieves a list of RadioButtonFieldState for a specified fieldName.
radioGroup<T>(String fieldName) → RadioGroupFieldState<T>

Available on BaseBondFormState<dynamic, Error>, provided by the FieldBondFormState extension

Retrieves the state of the radio group field for a specified fieldName.
textField(String fieldName) → TextFieldState

Available on BaseBondFormState<dynamic, Error>, provided by the FieldBondFormState extension

Retrieves the TextFieldState for a given text field.