asyncDropDownField<T> method
Retrieves the state of the async dropdown field for a specified fieldName.
This method retrieves the state of the async dropdown field identified by the provided fieldName.
- Parameter
fieldNameThe name of the async dropdown field to retrieve the state from. - Returns: The state of the async dropdown field.
- Throws: ArgumentError if the field doesn't exist.
Implementation
AsyncDropDownFieldState<T> asyncDropDownField<T>(String fieldName) {
return get<AsyncDropDownFieldState<T>, T>(fieldName);
}