asyncDropDownItems<T> method
Retrieves the list of dropdown items for a specified fieldName.
This method retrieves the list of async dropdown items associated with the
async dropdown field identified by the provided fieldName.
- Parameter
fieldNameThe name of the async dropdown field to retrieve items from. - Returns: A list of DropDownItemState representing the items of the async dropdown field.
- Throws: ArgumentError if the field doesn't exist.
Implementation
Future<List<DropDownItemState<T>>> asyncDropDownItems<T>(String fieldName) {
return asyncDropDownField<T>(fieldName).resolvedItems;
}