asyncRadioGroup<T> method
Retrieves the state of the async radio group field for a specified fieldName.
This method retrieves the state of the async radio group field identified by the provided fieldName.
- Parameter
fieldNameThe name of the async radio group field to retrieve the state from. - Returns: The state of the async radio group field.
- Throws: ArgumentError if the field doesn't exist.
Implementation
AsyncRadioGroupFieldState<T> asyncRadioGroup<T>(String fieldName) {
return get<AsyncRadioGroupFieldState<T>, T>(fieldName);
}