checkboxGroup<T> method
Retrieves the state of the checkbox group field for a specified fieldName.
This method retrieves the state of the checkbox group field identified by the provided fieldName.
- Parameter
fieldNameThe name of the checkbox group field to retrieve the state from. - Returns: The state of the checkbox group field.
- Throws: ArgumentError if the field doesn't exist.
Implementation
CheckboxGroupFieldState<T> checkboxGroup<T>(String fieldName) {
return get<CheckboxGroupFieldState<T>, Set<T>>(fieldName);
}