dateField method
Retrieves the state of the date field for a specified fieldName.
This method retrieves the state of the date field identified by the provided fieldName.
- Parameter
fieldNameThe name of the date field to retrieve the state from. - Returns: The state of the date field.
- Throws: ArgumentError if the field doesn't exist.
Implementation
DateFieldState dateField(String fieldName) {
return get<DateFieldState, DateTime?>(fieldName);
}