fileField method
Retrieves the state of the file field for a specified fieldName.
This method retrieves the state of the file field identified by the provided fieldName.
- Parameter
fieldNameThe name of the file field to retrieve the state from. - Returns: The state of the file field.
- Throws: ArgumentError if the field doesn't exist.
Implementation
FileFieldState fileField(String fieldName) {
return get<FileFieldState, File?>(fieldName);
}