fields abstract method
Returns the map of field names to their corresponding FormFieldState.
Implementation
Map<String, FormFieldState> fields();
Returns the map of field names to their corresponding FormFieldState.
Map<String, FormFieldState> fields();