FormFieldState<T> constructor
FormFieldState<T> ({})
Creates a new instance of FormFieldState.
valueThe initial value of the form field.errorAn optional error message initially associated with the field.labelThe label or name of the form field (required).touchedIndicates whether the field has been touched (default isfalse).validateOnUpdateIndicates whether validation should occur on updates (default istrue).rulesThe list of validation rules to apply to the form field (default is an empty list).
Implementation
FormFieldState({
required this.value,
this.error,
required this.label,
this.touched = false,
this.validateOnUpdate = false,
this.rules = const [],
});