copyWithNullable method

FormFieldState<T> copyWithNullable({
  1. T? value,
})

A null-tolerant version of copyWith, allowing you to explicitly set fields to null.

This is useful for form reset behaviors like clearing a field's value or removing its error.

Implementation

FormFieldState<T> copyWithNullable({
  T? value,
}) {
  ;
  return copyWith(
    value: value,
  );
}