Same<T> class

A validation rule that checks if a value is the same as the value of another field.

This rule validates that the input value is the same as the value of another field.

Inheritance

Constructors

Same(String otherField, {String? message})
Creates a new instance of the Same validation rule.

Properties

hashCode → int
The hash code for this object.
no setterinherited
l10n → ValidatorLocalizations
The ValidatorLocalizations instance used for localization of validation messages. It's obtained through a service locator (sl) for convenience.
no setterinherited
otherField → String
The name of the other field to compare values against.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

message(String fieldName) → String
Retrieves the validation message to be displayed.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validate(T value, Map<String, FormFieldState> fields) → bool
Validates the given value against the validation rule.
override
validatorMessage(String fieldName) → String
Retrieves the validator message for the field.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited