Size class

A validation rule that checks if a string has a specified size (length).

This rule validates that the input string has the specified size (length).

Inheritance

Constructors

Size(int size, {String? message})
Creates a new instance of the Size validation rule.

Properties

hashCode → int
The hash code for this object.
no setterinherited
l10n → ValidatorLocalizations
The ValidatorLocalizations instance used for localization of validation messages. It's obtained through a service locator (sl) for convenience.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
The required size (length) for the string.
final

Methods

message(String fieldName) → String
Retrieves the validation message to be displayed.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validate(String value, Map<String, FormFieldState> fields) → bool
Validates the given value against the validation rule.
override
validatorMessage(String fieldName) → String
Retrieves the validator message for the field.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited