next method

Future<void> next()

Submits the current step and advances to the next step if successful.

Calls submit to perform the submission of the current step. If the submission is successful (BondFormStateStatus.submitted), it advances to the next step.

Implementation

Future<void> next() async {
  await submit();
  if (state.status == BondFormStateStatus.submitted) {
    parent.next();
  }
}