fields method
Returns the map of field names to their corresponding FormFieldState.
Implementation
@override
Map<String, FormFieldState> fields() => state.fields;
Returns the map of field names to their corresponding FormFieldState.
@override
Map<String, FormFieldState> fields() => state.fields;