asyncDropDownValue<T> method
Retrieves the selected value of the async dropdown field for a specified fieldName.
This method retrieves the currently selected value of the async dropdown field
identified by the provided fieldName.
- Parameter
fieldNameThe name of the async dropdown field to retrieve the value from. - Returns: The selected value of the async dropdown field, or
nullif no value is selected. - Throws: ArgumentError if the field doesn't exist.
Implementation
T asyncDropDownValue<T>(String fieldName) {
return asyncDropDownField<T>(fieldName).value;
}