asyncHiddenFieldValue<T> method

T asyncHiddenFieldValue<T>(
  1. String fieldName
)

Retrieves the value of an async hidden field for a specified fieldName.

This method simplifies fetching the current value of an async hidden field.

  • Parameter fieldName The name of the async hidden field to fetch.
  • Returns: The current value of the async hidden field as a T, or null if not set.
  • Throws: ArgumentError if the field doesn't exist.

Implementation

T asyncHiddenFieldValue<T>(String fieldName) {
  return asyncHiddenField<T>(fieldName).value;
}