asyncRadioGroupValue<T> method

T asyncRadioGroupValue<T>(
  1. String fieldName
)

Retrieves the value of an AsyncRadioGroupFieldState for a specified fieldName.

This method simplifies fetching the current value of an async radio button group.

  • Parameter fieldName The name of the field to fetch.
  • Returns: The current value of the field or null if not set.
  • Throws: ArgumentError if the field doesn't exist.

Implementation

T asyncRadioGroupValue<T>(String fieldName) {
  return asyncRadioGroup<T>(fieldName).value;
}