checkboxValue<T> method
Retrieves the value of a checkbox field for a specified fieldName.
This method simplifies fetching the current value of a checkbox.
- Parameter
fieldNameThe name of the field to fetch. - Returns: The current value of the field.
- Throws: ArgumentError if the field doesn't exist.
Implementation
bool checkboxValue<T>(String fieldName) {
return checkbox(fieldName).value;
}