dropDownValue<T> method
Retrieves the selected value of the dropdown field for a specified fieldName.
This method retrieves the currently selected value of the dropdown field
identified by the provided fieldName.
- Parameter
fieldNameThe name of the dropdown field to retrieve the value from. - Returns: The selected value of the dropdown field, or
nullif no value is selected. - Throws: ArgumentError if the field doesn't exist.
Implementation
T dropDownValue<T>(String fieldName) {
return dropDownField<T>(fieldName).value;
}