fileFieldValue method
Retrieves the value of a file field for a specified fieldName.
This method simplifies fetching the current value of a file field.
- Parameter
fieldNameThe name of the file field to fetch. - Returns: The current value of the file field as a
File, ornullif not set. - Throws: ArgumentError if the field doesn't exist.
Implementation
File? fileFieldValue(String fieldName) {
return fileField(fieldName).value;
}