updateAsyncRadioGroup<T> method
Updates an AsyncRadioGroupFieldState with a given value.
fieldNameThe name of the async radio group field to update.valueThe new value for the async radio group field.
Implementation
void updateAsyncRadioGroup<T>(String fieldName, T value) {
updateValue<AsyncRadioGroupFieldState<T>, T>(fieldName, value);
}