dateFormatValidationMessage method
Generates a validation error message for a field that should comply with a specific date format.
This message indicates that the fieldName must be in the format format.
Implementation
String dateFormatValidationMessage(String fieldName, String format) {
return Intl.message(
'$fieldName must be in the format $format.',
name: 'dateFormatValidationMessage',
desc:
'Validation message for a field that should comply with a specific format',
args: [fieldName, format],
locale: localeName,
);
}