sameValidationMessage method
Generates a validation error message for a field that should have the same value as another field.
This message indicates that the fieldName must have the same value as field.
Implementation
String sameValidationMessage(String fieldName, String field) {
return Intl.message(
'$fieldName must have the same value as $field.',
name: 'sameValidationMessage',
desc:
'Validation message for a field that should have the same value as another field',
args: [fieldName, field],
locale: localeName,
);
}