ignoreEmptyValues property
bool
get
ignoreEmptyValues
Whether to exclude null, empty String, and int == 0 from the body.
Defaults to true. Set to false if you want to allow those values.
Implementation
bool get ignoreEmptyValues => true;