BondFormState<Success, Failure extends Error> class
Represents the state of a form with its fields and submission status.
- Inheritance
-
- Object
- BaseBondFormState<
Success, Failure> - BondFormState
- Available extensions
Constructors
-
BondFormState({required Map<
String, FormFieldState> fields, BondFormStateStatus status = BondFormStateStatus.pristine, Success? success, Failure? failure}) - Creates a BondFormState with the provided parameters.
Properties
- canSubmit → bool
-
Available on BondFormState<
Success, Failed> , provided by the XBondFormState extensionno setter - failed → bool
-
Available on BondFormState<
Success, Failed> , provided by the XBondFormState extensionno setter - failure → Failure
-
Retrieves the failure result of the form submission.
no setterinherited
- failureResult → Failure?
-
Stores the failure result of the form submission.
finalinherited
-
fields
→ Map<
String, FormFieldState> -
A map of field names to their corresponding state objects.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- loading → bool
-
Available on BondFormState<
Success, Failed> , provided by the XBondFormState extensionno setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → BondFormStateStatus
-
The current status of the form.
finalinherited
- submitted → bool
-
Available on BondFormState<
Success, Failed> , provided by the XBondFormState extensionno setter - success → Success
-
Retrieves the success result of the form submission.
no setterinherited
- successResult → Success?
-
Stores the success result of the form submission.
finalinherited
Methods
-
asyncDropDownField<
T> (String fieldName) → AsyncDropDownFieldState< T> -
Available on BaseBondFormState<
Retrieves the state of the async dropdown field for a specifieddynamic, Error> , provided by the FieldBondFormState extensionfieldName. -
asyncDropDownItems<
T> (String fieldName) → Future< List< DropDownItemState< >T> > -
Available on BaseBondFormState<
Retrieves the list of dropdown items for a specifieddynamic, Error> , provided by the FieldBondFormState extensionfieldName. -
asyncDropDownValue<
T> (String fieldName) → T -
Available on BaseBondFormState<
Retrieves the selected value of the async dropdown field for a specifieddynamic, Error> , provided by the ValueBondFormState extensionfieldName. -
asyncHiddenField<
T> (String fieldName) → AsyncHiddenFieldState< T> -
Available on BaseBondFormState<
Retrieves the async hidden field state for a specifieddynamic, Error> , provided by the FieldBondFormState extensionfieldName. -
asyncHiddenFieldValue<
T> (String fieldName) → T -
Available on BaseBondFormState<
Retrieves the value of an async hidden field for a specifieddynamic, Error> , provided by the ValueBondFormState extensionfieldName. -
asyncRadioButtonsOf<
T> (String fieldName) → Future< List< RadioButtonFieldState< >T> > -
Available on BaseBondFormState<
Retrieves a list of RadioButtonFieldState for a specifieddynamic, Error> , provided by the FieldBondFormState extensionfieldName. -
asyncRadioGroup<
T> (String fieldName) → AsyncRadioGroupFieldState< T> -
Available on BaseBondFormState<
Retrieves the state of the async radio group field for a specifieddynamic, Error> , provided by the FieldBondFormState extensionfieldName. -
asyncRadioGroupValue<
T> (String fieldName) → T -
Available on BaseBondFormState<
Retrieves the value of andynamic, Error> , provided by the ValueBondFormState extensionAsyncRadioGroupFieldStatefor a specifiedfieldName. -
checkbox(
String fieldName) → CheckboxFieldState< bool> -
Available on BaseBondFormState<
Retrieves the state of the checkbox field for a specifieddynamic, Error> , provided by the FieldBondFormState extensionfieldName. -
checkboxesOf<
T> (String fieldName) → List< CheckboxFieldState< T> > -
Available on BaseBondFormState<
Retrieves a list of CheckboxFieldState for a specifieddynamic, Error> , provided by the FieldBondFormState extensionfieldName. -
checkboxGroup<
T> (String fieldName) → CheckboxGroupFieldState< T> -
Available on BaseBondFormState<
Retrieves the state of the checkbox group field for a specifieddynamic, Error> , provided by the FieldBondFormState extensionfieldName. -
checkboxGroupValue<
T> (String fieldName) → T? -
Available on BaseBondFormState<
Retrieves the first selected value of a checkbox group for a specifieddynamic, Error> , provided by the ValueBondFormState extensionfieldName. -
checkboxSelected<
T> (String fieldName, T value) → bool -
Available on BaseBondFormState<
Checks if a specific value is selected within a checkbox group.dynamic, Error> , provided by the ValueBondFormState extension -
checkboxValue<
T> (String fieldName) → bool -
Available on BaseBondFormState<
Retrieves the value of a checkbox field for a specifieddynamic, Error> , provided by the ValueBondFormState extensionfieldName. -
checkboxValues<
T> (String fieldName) → Set< T> -
Available on BaseBondFormState<
Retrieves the selected values of a checkbox group for a specifieddynamic, Error> , provided by the ValueBondFormState extensionfieldName. -
copyWith<
State extends BaseBondFormState< (Success, Failure> >{Map< String, FormFieldState> ? fields, BondFormStateStatus? status, Success? success, Failure? failure}) → State -
Creates a copy of this BondFormState with optional parameter overrides.
override
-
dateField(
String fieldName) → DateFieldState -
Available on BaseBondFormState<
Retrieves the state of the date field for a specifieddynamic, Error> , provided by the FieldBondFormState extensionfieldName. -
dateFieldValue(
String fieldName) → DateTime? -
Available on BaseBondFormState<
Retrieves the value of a date field for a specifieddynamic, Error> , provided by the ValueBondFormState extensionfieldName. -
dropDownField<
T> (String fieldName) → DropDownFieldState< T> -
Available on BaseBondFormState<
Retrieves the state of the dropdown field for a specifieddynamic, Error> , provided by the FieldBondFormState extensionfieldName. -
dropDownItems<
T> (String fieldName) → List< DropDownItemState< T> > -
Available on BaseBondFormState<
Retrieves the list of dropdown items for a specifieddynamic, Error> , provided by the FieldBondFormState extensionfieldName. -
dropDownValue<
T> (String fieldName) → T -
Available on BaseBondFormState<
Retrieves the selected value of the dropdown field for a specifieddynamic, Error> , provided by the ValueBondFormState extensionfieldName. -
error<
T extends FormFieldState< (G> , G>String fieldName) → String? -
Retrieves the error message for a form field by its
fieldName.inherited -
fileField(
String fieldName) → FileFieldState -
Available on BaseBondFormState<
Retrieves the state of the file field for a specifieddynamic, Error> , provided by the FieldBondFormState extensionfieldName. -
fileFieldValue(
String fieldName) → File? -
Available on BaseBondFormState<
Retrieves the value of a file field for a specifieddynamic, Error> , provided by the ValueBondFormState extensionfieldName. -
get<
T extends FormFieldState< (G> , G>String fieldName) → T -
Retrieves the state of a form field by its
fieldName.inherited -
Available on BaseBondFormState<
Retrieves the hidden field state for a specifieddynamic, Error> , provided by the FieldBondFormState extensionfieldName. -
Available on BaseBondFormState<
Retrieves the value of a hidden field for a specifieddynamic, Error> , provided by the ValueBondFormState extensionfieldName. -
label<
T extends FormFieldState< (G> , G>String fieldName) → String -
Retrieves the label for a form field by its
fieldName.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
radioButtonsOf<
T> (String fieldName) → List< RadioButtonFieldState< T> > -
Available on BaseBondFormState<
Retrieves a list of RadioButtonFieldState for a specifieddynamic, Error> , provided by the FieldBondFormState extensionfieldName. -
radioGroup<
T> (String fieldName) → RadioGroupFieldState< T> -
Available on BaseBondFormState<
Retrieves the state of the radio group field for a specifieddynamic, Error> , provided by the FieldBondFormState extensionfieldName. -
radioGroupValue<
T> (String fieldName) → T -
Available on BaseBondFormState<
Retrieves the value of adynamic, Error> , provided by the ValueBondFormState extensionRadioGroupFieldStatefor a specifiedfieldName. -
required(
) → RequiredValues -
Available on BaseBondFormState<
Retrieves thedynamic, Error> , provided by the ValueBondFormState extensionRequiredValuesextension for the current form state. -
textField(
String fieldName) → TextFieldState -
Available on BaseBondFormState<
Retrieves the TextFieldState for a given text field.dynamic, Error> , provided by the FieldBondFormState extension -
textFieldValue(
String fieldName) → String? -
Available on BaseBondFormState<
Retrieves the value of a text field for a specifieddynamic, Error> , provided by the ValueBondFormState extensionfieldName. -
toString(
) → String -
A string representation of this object.
inherited
-
valid<
T extends FormFieldState< (G> , G>String fieldName) → bool -
Checks the validity of a form field by its
fieldName.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
String fieldName) → FormFieldState -
Allows accessing the state of a form field using the subscript operator.
inherited