asyncHiddenField<T> method
Retrieves the async hidden field state for a specified fieldName.
- Parameter
fieldNameThe name of the async hidden field to fetch. - Returns: The async hidden field state.
- Throws: ArgumentError if the field doesn't exist.
Implementation
AsyncHiddenFieldState<T> asyncHiddenField<T>(String fieldName) {
return get<AsyncHiddenFieldState<T>, T>(fieldName);
}