TextFieldFormController<Success, Failure extends Error, State extends BaseBondFormState<Success, Failure> > extension
A collection of utilities to work with TextFieldState inside BaseFormController.
This extension provides access to the TextEditingController for a field,
ensures it's observed for changes, and allows safe disposal of listeners.
- on
-
- BaseFormController<
Success, Failure, State>
- BaseFormController<
Methods
-
removeTextFieldFocusListener(
String fieldName) → void -
Available on BaseFormController<
Removes the focus listener for the specified text field. This is useful when cleaning up resources, such as duringSuccess, Failure, State> , provided by the TextFieldFormController extensiononClose()in a controller. -
removeTextFieldListener(
String fieldName) → void -
Available on BaseFormController<
Remove the listener registered for the given text field, if any.Success, Failure, State> , provided by the TextFieldFormController extension -
textFieldController(
String fieldName) → TextEditingController -
Available on BaseFormController<
Retrieves the TextEditingController for a given text field and ensures it is observed.Success, Failure, State> , provided by the TextFieldFormController extension -
textFieldFocusNode(
String fieldName) → FocusNode -
Available on BaseFormController<
Retrieves the FocusNode for a given text field.Success, Failure, State> , provided by the TextFieldFormController extension