TransformersRegistry class
A registry for managing field transformers, allowing custom transformations of form field values based on their types.
Constructors
Properties
-
factoriesByKey
→ Map<
String, FieldTransformerFactory< dynamic, Object?> > -
final
-
factoriesByType
→ Map<
Type, FieldTransformerFactory< dynamic, Object?> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register<
T, G extends Object?> (FieldTransformer< T, G?> transformationFunction) → void - Registers a transformer function for a specific field type.
-
registerForField<
T, G extends Object?> (String fieldKey, FieldTransformer< T, G?> transformationFunction) → void - Registers a transformer for a specific field name (key).
-
toString(
) → String -
A string representation of this object.
inherited
-
transform(
dynamic value, {String? fieldKey}) → dynamic - Transforms a field value using the appropriate transformer registered for its type.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited