asyncHiddenFieldValue<T> method
Retrieves the value of an async hidden field for a specified fieldName.
This method simplifies fetching the current value of an async hidden field.
- Parameter
fieldNameThe name of the async hidden field to fetch. - Returns: The current value of the async hidden field as a
T, ornullif not set. - Throws: ArgumentError if the field doesn't exist.
Implementation
T asyncHiddenFieldValue<T>(String fieldName) {
return asyncHiddenField<T>(fieldName).value;
}